Page 123 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 123

Home

    principal driving force, more fundamental than their
    political and economic pretensions. Militant atheism is

    1 yoad tO . ”

    not merely incidental or marginal to Communist policy;
    it is not a side effect, but the central pivot.

    To carry out this policy in the Soviet Union, tens of
    millions of innocent human beings were systematically
    tortured, and murdered. Out of 60,000 churches in 1914,
    by 1941 only 100 remained. While all of this was going
    on, it was business as usual for the American
    businessmen who helped set up the Soviets. For the
    majority of church leaders in America, it was silence.

    As was the case with Mexico, when the Communist
    government was about to fall it was the United States

    government that came to its rescue. This crisis came
    about when Stalin's government was bankrupt and
    staying alive by check kiting. At this point President
    Roosevelt gave the Communists diplomatic recognition,
    making it possible for them to obtain credit. From that
    time on the United States government has done
    everything possible to help the Communist leaders in the
    Soviet Union stay in power.

    Although ignored by the CFR-controlled American
    news media, much of what is known about past and
    present conditions in the Soviet Union has been revealed
    by defectors. One of these important defectors is Lev
    Alburt, a Soviet scientist who became an International
    Chess Grandmaster in order to escape and become an
    American citizen. Twice he earned the title "U. S. Chess

    118

    The Secret Side of History